.. _ref_release_notes:

Release notes
#############

This document contains the release notes for the ``Ansys Tools Repo Sync`` project.

.. vale off

.. towncrier release notes start

`1.5.0 <https://github.com/ansys/ansys-tools-repo-sync/releases/tag/v1.5.0>`_ - March 04, 2026
==============================================================================================

.. tab-set::


  .. tab-item:: Added

    .. list-table::
        :header-rows: 0
        :widths: auto

        * - Upgrade repository
          - `#9713 <https://github.com/ansys/ansys-tools-repo-sync/pull/9713>`_


.. vale on